[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[elpa] externals/jinx 065e876c64 1/2: Use terminology "dynamic module" i
From: |
ELPA Syncer |
Subject: |
[elpa] externals/jinx 065e876c64 1/2: Use terminology "dynamic module" instead of "native module" |
Date: |
Wed, 29 Mar 2023 08:58:40 -0400 (EDT) |
branch: externals/jinx
commit 065e876c640447bf0396386a37fedfb9364ef2b8
Author: Daniel Mendler <mail@daniel-mendler.de>
Commit: Daniel Mendler <mail@daniel-mendler.de>
Use terminology "dynamic module" instead of "native module"
The word "native" would be more meaningful but the Elisp manual refers
to these modules as "dynamically-loaded" or "dynamic" modules.
---
README.org | 3 ++-
jinx.el | 14 +++++++-------
2 files changed, 9 insertions(+), 8 deletions(-)
diff --git a/README.org b/README.org
index 1e7c0a0c6e..e90acb98b8 100644
--- a/README.org
+++ b/README.org
@@ -22,7 +22,8 @@ window boundaries and text folding are taken into account.
Jinx binds directly
to the native libenchant API, such that process communication with a backend
Aspell process can be avoided. Libenchant is widely used as spell-checking API
by text editors and supports [[https://nuspell.github.io/][Nuspell]],
[[http://hunspell.github.io/][Hunspell]], [[http://aspell.net/][Aspell]] and a
few lesser known
-backends. Jinx automatically compiles and loads the native module at startup.
+backends. Jinx automatically compiles =jinx-mod.c= and loads the dynamic
module at
+startup.
Jinx supports multiple languages in a buffer at the same time via the
=jinx-languages= customization variable. It offers flexible settings to ignore
diff --git a/jinx.el b/jinx.el
index c5c5d79f9d..d48e61e222 100644
--- a/jinx.el
+++ b/jinx.el
@@ -36,11 +36,11 @@
;; that process communication with a backend Aspell process can be
;; avoided. Libenchant is widely used as spell-checking API by text
;; editors and supports Nuspell, Hunspell, Aspell and a few lesser
;; known backends. Jinx automatically compiles and loads the native
;; module at startup. Libenchant must be installed on your system for
;; compilation. If `pkg-config' is available it will be used to
;; locate libenchant. On Debian or Ubuntu, install the packages
;; `libenchant-2-2', `libenchant-2-dev' and `pkg-config'.
;;
;; Jinx supports multiple languages in a buffer at the same time via
;; the `jinx-languages' customization variable. It offers flexible
@@ -439,10 +439,10 @@ Returns a pair of updated (START END) bounds."
nil #'jinx--timer-handler))))
(defun jinx--load-module ()
- "Compile and load native module."
+ "Compile and load dynamic module."
(unless (fboundp #'jinx--mod-dict)
(unless module-file-suffix
- (error "Jinx: Native modules are not supported"))
+ (error "Jinx: Dynamic modules are not supported"))
(let ((default-directory
(file-name-directory (locate-library "jinx.el" t)))
(module (file-name-with-extension "jinx-mod" module-file-suffix)))
@@ -36,11 +36,11 @@
;; avoided. Libenchant is widely used as spell-checking API by text
;; editors and supports Nuspell, Hunspell, Aspell and a few lesser
-;; known backends. Jinx automatically compiles and loads the native
-;; module at startup. Libenchant must be installed on your system for
-;; compilation. If `pkg-config' is available it will be used to
-;; locate libenchant. On Debian or Ubuntu, install the packages
-;; `libenchant-2-2', `libenchant-2-dev' and `pkg-config'.
+;; known backends. Jinx automatically compiles `jinx-mod.c' and loads
+;; the dynamic module at startup. Libenchant must be installed on
+;; your system for compilation. If `pkg-config' is available it will
+;; be used to locate libenchant. On Debian or Ubuntu, install the
+;; packages `libenchant-2-2', `libenchant-2-dev' and `pkg-config'.
;;
;; Jinx supports multiple languages in a buffer at the same time via